# lagcorp
It is a sample version to learn pypi

## Installation
```pip install lagcorp```

## How to use it?
```from lagcorp import camper```
Main releases will be given soon
Docs will be updated soon

## License

© 2021 Iamrealbhuvi, Lagcorp

This repository is licensed under the MIT license. See LICENSE for details.
